@@ -39,6 +39,10 @@
 
 #undef G_COMPILED_WITH_DEBUGGING
 #undef G_THREADS_ENABLED
+
+#undef GLIB_SIZEOF_GMUTEX
+#undef GLIB_BYTE_CONTENTS_GMUTEX
+
 #undef HAVE_BROKEN_WCTYPE
 #undef HAVE_DOPRNT
 #undef HAVE_FLOAT_H
