@@ -301,6 +301,16 @@ extern "C" {
       ((type *) g_realloc (mem, (unsigned) sizeof (type) * (count)))
 #endif /* __DMALLOC_H__ */
 
+/* alloca-based counterparts of the above routines */
+#if G_HAVE_ALLOCA
+#  define g_alloca alloca
+#  define g_new_a(type, count)	  \
+      ((type *) alloca ((unsigned) sizeof (type) * (count)))
+#  define g_new0_a(type, count)	  \
+      ((type *) memset (alloca ((unsigned) sizeof (type) * (count)), 0, \
+      			((unsigned) sizeof (type) * (count))))
+#endif
+
 #define g_mem_chunk_create(type, pre_alloc, alloc_type)	( \
   g_mem_chunk_new (#type " mem chunks (" #pre_alloc ")", \
 		   sizeof (type), \
@@ -1455,6 +1465,54 @@ gchar*	 g_strescape		(gchar	      *string);
 gpointer g_memdup		(gconstpointer mem,
 				 guint	       byte_size);
 
+/* Macros for dynamic strings via fast stack allocation
+ * All macros take a special first argument: the target gchar* string
+ */
+#if G_HAVE_ALLOCA
+
+#  define g_strdup_a(newstr,str) G_STMT_START { \
+	  if ((str) == NULL) (newstr) = NULL;	\
+	  else {				\
+	    const char *__old = (str);		\
+	    char *__new;			\
+	    size_t __len = strlen (__old) + 1;	\
+	    __new = alloca (__len);		\
+	    memcpy (__new, __old, __len);	\
+	    (newstr) = __new;			\
+   	  }					\
+   } G_STMT_END
+
+#  define g_strndup_a(newstr,str,n) G_STMT_START { \
+	  if ((str) == NULL) (newstr) = NULL;	\
+	  else {				\
+	    const char *__old = (str);		\
+	    char *__new;			\
+	    size_t __len = strlen (__old);	\
+	    if (__len > (n)) __len = (n);	\
+	    __new = alloca (__len + 1);		\
+	    memcpy (__new, __old, __len);	\
+	    __new[__len] = 0;			\
+	    (newstr) = __new;			\
+   	  }					\
+   } G_STMT_END
+
+#  define g_strconcat3_a(newstr,str1,str2,str3) G_STMT_START { \
+	  size_t __len1 = ((str1) == (gchar*)NULL) ? 0 : strlen((str1)); \
+	  size_t __len2 = ((str2) == (gchar*)NULL) ? 0 : strlen((str2)); \
+	  size_t __len3 = ((str3) == (gchar*)NULL) ? 0 : strlen((str3)); \
+	  char *__sptr, *__new = \
+	  	alloca (__len1 + __len2 + __len3 + 1); \
+	  __sptr = __new; \
+	  if (__len1){memcpy (__sptr, (str1), __len1); __sptr += __len1;} \
+	  if (__len2){memcpy (__sptr, (str2), __len2); __sptr += __len2;} \
+	  if (__len3){memcpy (__sptr, (str3), __len3); __sptr += __len3;} \
+	  *__sptr = '\0'; \
+	  (newstr) = __new; \
+   } G_STMT_END
+
+#endif /* G_HAVE_ALLOCA */
+
+
 /* NULL terminated string arrays.
  * g_strsplit() splits up string into max_tokens tokens at delim and
  * returns a newly allocated string array.
