@@ -39,6 +39,14 @@ else \
 #define	C2P(c)		((gpointer) ((long) (c)))
 #define	P2C(p)		((gchar) ((long) (p)))
 
+#define GLIB_TEST_STRING "el dorado "
+#define GLIB_TEST_STRING_5 "el do"
+
+typedef struct {
+	guint age;
+	gchar name[40];
+} GlibTestInfo;
+
 static gboolean
 node_build_string (GNode    *node,
 		   gpointer  data)
@@ -291,6 +299,7 @@ main (int   argc,
   GRelation *relation;
   GTuples *tuples;
   gint data [1024];
+  GlibTestInfo *gti;
   struct {
     gchar *filename;
     gchar *dirname;
@@ -745,6 +754,37 @@ main (int   argc,
 
   g_print ("ok\n");
 
+  g_print ("checking g_strdup...");
+  g_assert(g_strdup(NULL) == NULL);
+  string = g_strdup(GLIB_TEST_STRING);
+  g_assert(string != NULL);
+  g_assert(strcmp(string, GLIB_TEST_STRING) == 0);
+  g_free(string);
+
+  g_print ("ok\n");
+
+  g_print ("checking g_strconcat...");
+  string = g_strconcat(GLIB_TEST_STRING, NULL);
+  g_assert(string != NULL);
+  g_assert(strcmp(string, GLIB_TEST_STRING) == 0);
+  g_free(string);
+  string = g_strconcat(GLIB_TEST_STRING, GLIB_TEST_STRING, 
+  		       GLIB_TEST_STRING, NULL);
+  g_assert(string != NULL);
+  g_assert(strcmp(string, GLIB_TEST_STRING GLIB_TEST_STRING
+  			  GLIB_TEST_STRING) == 0);
+  g_free(string);
+  
+  g_print ("ok\n");
+
+  g_print ("checking g_strdup_printf...");
+  string = g_strdup_printf ("%05d %-5s", 21, "test");
+  g_assert (string != NULL);
+  g_assert (strcmp(string, "00021 test ") == 0);
+  g_free (string);
+
+  g_print ("ok\n");
+
   /* g_debug (argv[0]); */
 
   /* Relation tests */
@@ -857,11 +897,11 @@ main (int   argc,
   string = NULL;
   g_print (string);
 
-  g_print ("endian macro tests...");
+  g_print ("checking endian macros (host is ");
 #if G_BYTE_ORDER == G_BIG_ENDIAN
-  g_print ("big endian...");
+  g_print ("big endian)...");
 #else
-  g_print ("little endian...");
+  g_print ("little endian)...");
 #endif
   g_assert (GUINT16_SWAP_LE_BE (gu16t1) == gu16t2);  
   g_assert (GUINT32_SWAP_LE_BE (gu32t1) == gu32t2);  
@@ -870,5 +910,58 @@ main (int   argc,
 #endif
   g_print ("ok\n");
 
+#ifdef G_HAVE_ALLOCA
+  g_print ("checking alloca()-based allocation routines...");
+
+  string = g_alloca(80);
+  g_assert(string != NULL);
+  for (i = 0; i < 80; i++)
+    string[i] = 'x';
+  string[79] = 0;
+  g_assert(strlen(string) == 79);
+
+  gti = g_new_a(GlibTestInfo, 2);
+  string = g_alloca(2);
+  strcpy(string, "x");
+  for (i = 0; i < 2; i++) {
+    for (j = 0; j < 40; j++)
+      gti[i].name[j] = 'x';
+    gti[i].name[39] = 0;
+    g_assert(strlen(gti[i].name) == 39);
+    gti[i].age = 42;
+  }
+  g_assert(strcmp(string, "x") == 0);
+
+  string = g_new0_a(char, 40);
+  for (i = 0; i < 39; i++)
+    string[i] = 'x';
+  g_assert(strlen(string) == 39);
+
+  g_print ("ok\n");
+
+  g_print ("checking alloca()-based string duplication routines...");
+
+  g_strdup_a(string, GLIB_TEST_STRING);
+  g_assert(string != NULL);
+  g_assert(strcmp(string, GLIB_TEST_STRING) == 0);
+  g_strdup_a(string, NULL);
+  g_assert(string == NULL);
+
+  g_strndup_a(string, GLIB_TEST_STRING, 5);
+  g_assert(string != NULL);
+  g_assert(strlen(string) == 5);
+  g_assert(strcmp(string, GLIB_TEST_STRING_5) == 0);
+  g_strndup_a(string, NULL, 20);
+  g_assert(string == NULL);
+
+  g_strconcat3_a(string, GLIB_TEST_STRING, GLIB_TEST_STRING, GLIB_TEST_STRING);
+  g_assert(string != NULL);
+  g_assert(strcmp(string, GLIB_TEST_STRING GLIB_TEST_STRING
+  			  GLIB_TEST_STRING) == 0);
+
+  g_print ("ok\n");
+#endif
+
   return 0;
 }
+
